@@ -11,7 +11,7 @@
 
 #ifndef LOCALE_ALIAS_PATH
 #define LOCALE_ALIAS_PATH "/usr/share/local"
-#endif     
+#endif
 
 #include <stdlib.h>
 #ifdef __alpha
@@ -33,8 +33,8 @@ extern "C" {
 }
 #undef __BEGIN_DECLS
 #undef __END_DECLS
-#define __BEGIN_DECLS	extern "C" { 
-#define	__END_DECLS	} 
+#define __BEGIN_DECLS	extern "C" {
+#define	__END_DECLS	}
 #endif // _ARGZ_H_WORKAROUND_
 #endif // HAVE_ARGZ_H
 
@@ -56,7 +56,7 @@ extern "C" {
 # define alloca __builtin_alloca
 # define HAVE_ALLOCA 1
 #else
-# if defined HAVE_ALLOCA_H 
+# if defined HAVE_ALLOCA_H
 #  include <alloca.h>
 # else
 #  ifdef _AIX
@@ -92,13 +92,13 @@ extern int errno;
 #undef NULL
 #endif
 
-#define NULL 0 
+#define NULL 0
 
 #if HAVE_LIMITS_H
 # include <limits.h>
 #endif
 
-#if (defined HAVE_MMAP && defined HAVE_MUNMAP) 
+#if (defined HAVE_MMAP && defined HAVE_MUNMAP)
 # include <sys/mman.h>
 #endif
 
@@ -281,7 +281,7 @@ char *
 k_bindtextdomain(const char *domainname, const char *dirname)
 {
   struct binding *binding;
-  
+
   /* Some sanity checks.  */
   if (domainname == NULL || domainname[0] == '\0')
     return NULL;
@@ -483,11 +483,11 @@ k_dcgettext (const char *domainname, const char *msgid, const char *categoryvalu
   struct loaded_l10nfile *domain;
   struct binding *binding;
   char *dirname, *xdomainname;
-  const char *categoryname;  
+  const char *categoryname;
   char *single_locale;
   char *retval;
   int saved_errno = errno;
-  const char *_domainname = (domainname == 0L) ? _nl_current_default_domain : domainname;     
+  const char *_domainname = (domainname == 0L) ? _nl_current_default_domain : domainname;
 
   /* If no real MSGID is given return NULL.  */
   if (msgid == NULL)
@@ -742,13 +742,13 @@ stpcpy (char *dest, const char *src)
 
 
 int
-_nl_explode_name (char * name, const char **language, 
-		  const char **modifier, const char **territory, 
-		  const char **codeset, 
-		  const char **normalized_codeset, 
-		  const char **special, const char **sponsor, 
+_nl_explode_name (char * name, const char **language,
+		  const char **modifier, const char **territory,
+		  const char **codeset,
+		  const char **normalized_codeset,
+		  const char **special, const char **sponsor,
 		  const char **revision)
-     
+
 {
   enum { undecided, xpg, cen } syntax;
   char *cp;
@@ -888,7 +888,7 @@ static struct loaded_l10nfile *_nl_loaded_domains;
    the DOMAINNAME and CATEGORY parameters with respect to the currently
    established bindings.  */
 struct loaded_l10nfile *
-_nl_find_domain (const char *dirname, char *locale, 
+_nl_find_domain (const char *dirname, char *locale,
 		 const char *domainname)
 
 {
@@ -1108,13 +1108,13 @@ static inline int pop (int x)
 
 
 struct loaded_l10nfile *
-_nl_make_l10nflist (struct loaded_l10nfile **l10nfile_list, 
-		    const char *dirlist, size_t dirlist_len, 
+_nl_make_l10nflist (struct loaded_l10nfile **l10nfile_list,
+		    const char *dirlist, size_t dirlist_len,
 		    int mask, const char *language,
-		    const char *territory, const char *codeset, 
-		    const char *normalized_codeset, 
+		    const char *territory, const char *codeset,
+		    const char *normalized_codeset,
 		    const char *modifier, const char *special,
-		    const char *sponsor, const char *revision, 
+		    const char *sponsor, const char *revision,
 		    const char *filename, int do_allocate)
 {
   char *abs_filename;
@@ -1493,7 +1493,7 @@ _nl_expand_alias (const char *name)
       item.alias = name;
 
       if (nmap > 0)
-	  retval = (struct alias_map *) 
+	  retval = (struct alias_map *)
 	      bsearch (&item, map, nmap,
 		       sizeof (struct alias_map),
 		       (int (*) (const void *,
@@ -1686,7 +1686,7 @@ extend_alias_table ()
 
 
 static int
-alias_compare (const struct alias_map *map1, 
+alias_compare (const struct alias_map *map1,
 	       const struct alias_map *map2)
 {
 #if defined HAVE_STRCASECMP
@@ -1763,38 +1763,42 @@ bool checkTag(const char* tag, const char *in, int argc, char **argv, FILE *newF
 {
     char buffer[100];
     sprintf(buffer, "%s=", tag);
-    
+
     if (!strncmp(in, buffer, strlen(buffer))) {
-
-	fprintf(newFile, "%s\n", in);
-	
-	for (int i = 2; i < argc; i++) {
-	    const char *test = k_dcgettext(argv[0], in, argv[i]);
-
-           if (!strncmp(in + 1, buffer, strlen(buffer))) {
-               fprintf(stderr, "ERROR: translation of %s \"%s\" contains tag not at the beginning of line\n", argv[i], test);
-		continue;
-	    }
-
-	    if (!strcmp(test, buffer) || !strcmp(test, in))
-		continue;
-	    if (strncmp(test, tag, strlen(tag))) {
-		fprintf(stderr, "ERROR: %s's translation of \"%s\" doesn't fit tag\n", argv[i], in);
-		continue;
-	    }
-	    char out[3000];
-	    sprintf(out, "%s[%s]=%s", tag, argv[i], test + strlen(tag) + 1);
-	    // out[strlen(out) - strlen(tag) - 1] = 0;
-	    fprintf(newFile, "%s\n", out);
+		
+		fprintf(newFile, "%s\n", in);
+		
+		for (int i = 2; i < argc; i++) {
+			const char *test = k_dcgettext(argv[0], in, argv[i]);
+			
+			if (!strncmp(in + 1, buffer, strlen(buffer))) {
+				fprintf(stderr, "ERROR: translation of %s \"%s\" contains tag not at the beginning of line\n", argv[i], test);
+				continue;
+			}
+			
+			if (!strcmp(test, buffer) || !strcmp(test, in))
+				continue;
+			if (strncmp(test, tag, strlen(tag))) {
+				fprintf(stderr, "ERROR: %s's translation of \"%s\" doesn't fit tag\n", argv[i], in);
+				continue;
+			}
+			if (strchr(test, '\n')) {
+				fprintf(stderr, "ERROR: %s's translation of \"%s\" contains a newline\n", argv[i], in);
+				continue;
+			}
+				char out[3000];
+				sprintf(out, "%s[%s]=%s", tag, argv[i], test + strlen(tag) + 1);
+				// out[strlen(out) - strlen(tag) - 1] = 0;
+				fprintf(newFile, "%s\n", out);
+			}
+			return true;
+		}
+		
+		sprintf(buffer, "%s[", tag);
+		if (!strncmp(in, buffer, strlen(buffer)))
+			return true;
+		return false;
 	}
-	return true;
-    }
-
-    sprintf(buffer, "%s[", tag);
-    if (!strncmp(in, buffer, strlen(buffer)))
-	return true;
-    return false;
-}
 	
 
 int main(int argc, char **argv)
@@ -1813,12 +1817,12 @@ int main(int argc, char **argv)
     k_bindtextdomain(argv[0], kdedir);
 
     FILE *f = fopen(argv[1], "rt");
-    
+
     if (!f) {
 	fprintf(stderr, "can't open file %s\n", argv[1]);
 	exit(1);
     }
-    
+
     char buffer[1000] = "";
     strcpy(buffer, argv[1]);
     strcat(buffer, ".new");
@@ -1829,8 +1833,8 @@ int main(int argc, char **argv)
     }
 
     char in[3000];
-  
-    
+
+
     while (fgets(in, 3000, f) != 0) {
 	
 	if (in[strlen(in) - 1] == '\n')
@@ -1848,6 +1852,12 @@ int main(int argc, char **argv)
 	if (checkTag("Keywords", in, argc, argv, newFile))
 	    continue;
 
+        if (checkTag("About", in, argc, argv, newFile))
+            continue;
+
+ 	if (checkTag("Description", in, argc, argv, newFile))
+            continue;
+
 	fprintf(newFile, "%s\n", in);
     }
     fclose(newFile);
